@@ -1,8 +1,8 @@
 /* copyright (c) 2022 - 2024 grunfink et al. / MIT license */
 
-#ifndef _XS_MIME
+#ifndef _XS_MIME_H
 
-#define _XS_MIME
+#define _XS_MIME_H
 
 const char *xs_mime_by_ext(const char *file);
 
@@ -11,11 +11,12 @@ extern const char *xs_mime_types[];
 #ifdef XS_IMPLEMENTATION
 
 /* intentionally brain-dead simple */
-/* CAUTION: sorted */
+/* CAUTION: sorted by extension */
 
 const char *xs_mime_types[] = {
     "3gp",      "video/3gpp",
     "aac",      "audio/aac",
+    "avif",     "image/avif",
     "css",      "text/css",
     "flac",     "audio/flac",
     "flv",      "video/flv",
@@ -55,19 +56,23 @@ const char *xs_mime_by_ext(const char *file)
     const char *ext = strrchr(file, '.');
 
     if (ext) {
-        const char **p = xs_mime_types;
-        xs *uext       = xs_tolower_i(xs_dup(ext + 1));
+        xs *uext = xs_tolower_i(xs_dup(ext + 1));
+        int b = 0;
+        int t = xs_countof(xs_mime_types) / 2 - 2;
 
-        while (*p) {
-            int c;
+        while (t >= b) {
+            int n = (b + t) / 2;
+            const char *p = xs_mime_types[n * 2];
 
-            if ((c = strcmp(*p, uext)) == 0)
-                return p[1];
+            int c = strcmp(uext, p);
+
+            if (c < 0)
+                t = n - 1;
             else
             if (c > 0)
-                break;
-
-            p += 2;
+                b = n + 1;
+            else
+                return xs_mime_types[(n * 2) + 1];
         }
     }
 
@@ -77,4 +82,4 @@ const char *xs_mime_by_ext(const char *file)
 
 #endif /* XS_IMPLEMENTATION */
 
-#endif /* XS_MIME */
+#endif /* XS_MIME_H */
